==> homesitemaker-v0.4.1.tar.gz: homesitemaker/includes/system_config.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//
// Configuration file for HomeSite M.A.K.E.R
//


// Path to the CONVERT utility of the ImageMagick tool
// You can use one of the following acording to your system
// or you can use "whereis" command to find the path to convert 
// utility in your system (use: whereis convert)
//
// FreeBSD 5.x /usr/local/bin/convert
// Slacakware 9.0 /usr/X11R6/bin/convert
// Red Hat 7.1 8 9 ????
// SuSe Linux 9.2 /usr/bin/convert
$CONVERT_PATH="/usr/local/bin/convert"; 
?>

==> homesitemaker-v0.4.4.tar.gz: homesitemaker/includes/system_config.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//
// Configuration file for HomeSite M.A.K.E.R
//


// PATH to the CONVERT utility from the ImageMagick toolkit
// Use one of the following acording to your system
// If your OS don't appear in the examples, use "whereis" command 
// to find the location of the convert binary
//
// FreeBSD 5.x /usr/local/bin/convert
// Slacakware 9.0 /usr/X11R6/bin/convert
// Fedora Core 3, SuSe Linux 9.2, 9.3 and OpenSuSE 10.0 /usr/bin/convert

$CONVERT_PATH="/usr/bin/convert";
#$CONVERT_PATH="/usr/local/bin/convert"; 
#$CONVERT_PATH="/usr/X11R6/bin/convert";
?>
